==> XIV_host_attach-1.1-suse-11-x64.tar.gz: opt/xiv/host_attach/lib/python/hostattachment/platform/service.py <==
#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import logging
from execute import ExternalCommand
from hostattachment.exceptions import HostAttachmentError

class GenericServiceManager(object):
    def __init__(self, service_name, daemon_name=''):
        self.service_name = service_name
        if daemon_name == '':
            self.daemon_name = '%sd' % service_name
        else:
            self.daemon_name = daemon_name
        self.get_init_script()
    
    def get_init_script(self):
        # TODO Don't GUESS the svc name, have a preset list of all possibilities
        ls_command = ExternalCommand('ls /etc/init.d/*%s* | grep -v boot' % self.service_name)
        ls_command.execute()
        self.init_script = ls_command.head(1)[0].split()[0].split('/').pop()
   
    def start(self):
        logging.info('starting the %s service' % self.service_name)
        start_command = ExternalCommand('/etc/init.d/%s start' % self.init_script)
        start_command.execute()
        if not start_command.is_error_free():
            if not start_command.contains('15 - already exists)'):
                raise HostAttachmentError("Failed starting the " + \
                    "\"%s\" service" % (self.init_script))
                return True
            else:
                return False
        else:
            return True

    def is_configured(self):
        service_is_running = self.is_daemon_running() and \
            self.service_status_check()

        chkconfig_is_set = self.is_chkconfig_set()

        return service_is_running and chkconfig_is_set

    def is_chkconfig_set(self):
        ps_command = ExternalCommand('chkconfig --list %s' % self.init_script)
        ps_command.execute()
        if ps_command.return_value == 0:
            for runlevel in [3, 4, 5]:
                if not ps_command.output.__contains__("%d:on" % runlevel):
                    return False # Service is off for at least one runlevel
        else:
            return False # Service is not registered in chkconfig

        return True

    def is_daemon_running(self):
        ps_command = ExternalCommand('ps -fade | grep %s | grep -v grep' % self.daemon_name)
        ps_command.execute()
        return ps_command.contains(self.daemon_name)

    def service_status_check(self):
        status_command = ExternalCommand('/etc/init.d/%s status' % self.init_script)
        status_command.execute()
        if status_command.return_value == 0:
            return True
        else:
            logging.error('%s service is not running' %  self.service_name)
            return False

    def configure(self):
        add_command = ExternalCommand('chkconfig --add %s' % self.init_script)
        add_command.execute()
        if add_command.return_value != 0:
            raise HostAttachmentError("Failed registering service")

        on_command = ExternalCommand('chkconfig --level 345 %s on' % self.init_script)
        on_command.execute()
        if add_command.return_value != 0:
            raise HostAttachmentError("Failed adding service to runlevels")

        return self.start()

==> XIV_host_attach-1.1.1-suse-11-x64.tar.gz: opt/xiv/host_attach/lib/python/hostattachment/platform/service.py <==
#-------------------------------------------------------------------------------------------------
# Copyright (c) International Business Machines Corp., 2009
#
# IBM XIV Storage System Software
#
# Licensed materials provided under the terms of the IBM International Program
# License Agreement. See the Software
# licensing materials that came with the IBM XIV Storage System for terms and
# conditions.
#
#-------------------------------------------------------------------------------------------------

import logging
from execute import ExternalCommand
from hostattachment.exceptions import HostAttachmentError

class GenericServiceManager(object):
    def __init__(self, service_name, daemon_name=''):
        self.service_name = service_name
        if daemon_name == '':
            self.daemon_name = '%sd' % service_name
        else:
            self.daemon_name = daemon_name
        self.get_init_script()
    
    def get_init_script(self):
        # TODO Don't GUESS the svc name, have a preset list of all possibilities
        ls_command = ExternalCommand('ls /etc/init.d/*%s* | grep -v boot' % self.service_name)
        ls_command.execute()
        self.init_script = ls_command.head(1)[0].split()[0].split('/').pop()
   
    def restart(self, ignore_retval = False):
        # We restart instead of start, for case that the service was already up
        # Restart returns error code 0 even when the stop phase fails
        logging.info('Restarting the %s service' % self.service_name)
        start_command = ExternalCommand('/etc/init.d/%s restart' % self.init_script)
        start_command.execute()
        if not ignore_retval and start_command.return_value != 0:
            raise HostAttachmentError("Failed starting the " + \
                "\"%s\" service" % (self.init_script))
        else:
            return True

    def is_configured(self):
        service_is_running = self.is_daemon_running() and \
            self.service_status_check()

        chkconfig_is_set = self.is_chkconfig_set()

        return service_is_running and chkconfig_is_set

    def is_chkconfig_set(self):
        ps_command = ExternalCommand('chkconfig --list %s' % self.init_script)
        ps_command.execute()
        if ps_command.return_value == 0:
            for runlevel in [3, 4, 5]:
                if not ps_command.output.__contains__("%d:on" % runlevel):
                    return False # Service is off for at least one runlevel
        else:
            return False # Service is not registered in chkconfig

        return True

    def is_daemon_running(self):
        ps_command = ExternalCommand('ps -fade | grep %s | grep -v grep' % self.daemon_name)
        ps_command.execute()
        return ps_command.contains(self.daemon_name)

    def service_status_check(self):
        status_command = ExternalCommand('/etc/init.d/%s status' % self.init_script)
        status_command.execute()
        if status_command.return_value == 0:
            return True
        else:
            logging.error('%s service is not running' %  self.service_name)
            return False

    def configure(self, ignore_service_retval = False):
        """Configures the service and restarts it.
        Restart will not check the retval if ignore_service_retval = True
        """
        add_command = ExternalCommand('chkconfig --add %s' % self.init_script)
        add_command.execute()
        if add_command.return_value != 0:
            raise HostAttachmentError("Failed registering service")

        on_command = ExternalCommand('chkconfig --level 345 %s on' % self.init_script)
        on_command.execute()
        if add_command.return_value != 0:
            raise HostAttachmentError("Failed adding service to runlevels")

        return self.restart(ignore_service_retval)
